import {Alert, Tooltip} from "@mantine/core";
import {IconBug} from "@tabler/icons-react";
import {useLocalStorage} from "@mantine/hooks";
import {ReactNode} from "react";


/**
 * Hook to manage the global state of all debug dialogs
 * Stores the state in local storage
 * @see ShowHelp
 * @see useLocalStorage
 * @returns {{showDebug: boolean, setShowDebug: (function(boolean): void), toggleShowDebug: (function(): void)}}
 */

// eslint-disable-next-line react-refresh/only-export-components
export const useShowDebug = (): {
    showDebug: boolean;
    setShowDebug: ((arg0: boolean) => void);
    toggleShowDebug: (() => void);
} => {
    const [value, setValue] = useLocalStorage({
        key: 'stuve-it-show-debug',
        defaultValue: 'false',
    })

    return {
        showDebug: value === 'true',
        setShowDebug: (value: boolean) => setValue(value ? 'true' : 'false'),
        toggleShowDebug: () => setValue(value => value === 'true' ? 'false' : 'true'),
    }
}

/**
 * Shows a help dialog if the user has not disabled it
 * @see useShowHelp
 * @param children - the content of the help dialog
 */
export default function ShowDebug({children}: { children: ReactNode }) {

    const {showDebug} = useShowDebug()

    if (!showDebug) {
        return null
    }

    return <Alert
        title={"Debug"}
        color={"orange"}
        icon={
            <Tooltip
                withArrow
                color={"orange"}
                label={"Du kannst in deinen Einstellungen den Debug Modus deaktivieren."}
            >
                <IconBug/>
            </Tooltip>
        }>
        {children}
    </Alert>
}