import {Alert, Tooltip} from "@mantine/core";
import {IconQuestionMark} from "@tabler/icons-react";
import {useLocalStorage} from "@mantine/hooks";
import {ReactNode} from "react";


/**
 * Hook to manage the global state of all help dialogs
 * Stores the state in local storage
 * @see ShowHelp
 * @see useLocalStorage
 * @returns {{showHelp: boolean, setShowHelp: (function(boolean): void), toggleShowHelp: (function(): void)}}
 */
// eslint-disable-next-line react-refresh/only-export-components
export const useShowHelp = (): { showHelp: boolean; setShowHelp: ((arg0: boolean) => void); toggleShowHelp: (() => void); } => {
    const [value, setValue] = useLocalStorage({
        key: 'stuve-it-show-help',
        defaultValue: 'true',
    })

    return {
        showHelp: value === 'true',
        setShowHelp: (value: boolean) => setValue(value ? 'true' : 'false'),
        toggleShowHelp: () => setValue(value => value === 'true' ? 'false' : 'true'),
    }
}

/**
 * Shows a help dialog if the user has not disabled it
 * @see useShowHelp
 * @param children - the content of the help dialog
 */
export default function ShowHelp({children}: { children: ReactNode }) {

    const {showHelp} = useShowHelp()

    if (!showHelp) {
        return null
    }

    return <Alert
        title={"Hilfe"}
        icon={
            <Tooltip
                withArrow
                label={"Du kannst in deinen Einstellungen die Hilfe deaktivieren."}
            >
                <IconQuestionMark/>
            </Tooltip>
        }>
        {children}
    </Alert>
}