import RecordSearchInput, {GenericRecordSearchInputProps} from "../input/RecordSearchInput.tsx";
import {LdapGroupModel} from "@/models/AuthTypes.ts";
import {usePB} from "@/lib/pocketbase.tsx";
import {IconUsersGroup} from "@tabler/icons-react";
import {useMutation} from "@tanstack/react-query";

export default function LdapGroupInput({
                                           label,
                                           description,
                                           selectedRecords,
                                           setSelectedRecords,
                                           placeholder
                                       }: GenericRecordSearchInputProps<LdapGroupModel>) {

    const {pb} = usePB()

    return (
        <RecordSearchInput
            <LdapGroupModel>
            label={label}
            description={description}
            selectedRecords={selectedRecords}
            setSelectedRecords={setSelectedRecords}
            recordToString={(group) => ({displayName: `${group.cn}`, description: group.description})}
            placeholder={placeholder || "Suche nach Gruppen ..."}
            leftSection={<IconUsersGroup size={18}/>}
            recordSearchMutation={
                useMutation({
                    mutationFn: async (search: string) => {
                        if (!search) {
                            return []
                        }
                        return (await pb.collection('ldap_groups').getList(1, 5, {
                            filter: `cn ~ "%${search}%"`,
                        })).items
                    }
                })
            }
        />
    )
}