import {useMutation} from "@tanstack/react-query";
import {IconUsers} from "@tabler/icons-react";
import {usePB} from "@/lib/pocketbase.tsx";
import {UserModal} from "@/models/AuthTypes.ts";
import RecordSearchInput, {GenericRecordSearchInputProps} from "../input/RecordSearchInput.tsx";


export default function UserInput(props: GenericRecordSearchInputProps<UserModal>) {

    const {pb} = usePB()

    return (
        <RecordSearchInput
            <UserModal>
            recordToString={(user) => ({displayName: `${user.givenName} ${user.sn}`})}
            {...props}
            placeholder={props.placeholder || "Suche nach Personen..."}
            leftSection={<IconUsers size={18}/>}
            recordSearchMutation={
                useMutation({
                    mutationFn: async (search: string) => {
                        if (!search) {
                            return []
                        }

                        return (await pb.collection('users').getList(1, 5, {
                            filter: `(username ~ "${
                                search.trim().toLowerCase().split(" ").map(s => s.trim()).join(".")
                            }%")`,
                        })).items
                    }
                })
            }
        />
    )
}

