import {useDisclosure} from "@mantine/hooks";
import {Button, Group, Modal} from "@mantine/core";
import {useLogin} from "@/components/auth/modals/hooks.ts";
import {IconLogin, IconX} from "@tabler/icons-react";

export default function PromptLoginModal({onAbort, description}: {
    description?: string
    onAbort: () => void
}) {
    const [open, openHandler] = useDisclosure(true)
    const {handler: loginHandler} = useLogin()
    return <Modal opened={open} onClose={openHandler.close} title={"Zugang beschränkt"}>
        <div className={"stack"}>

            {
                description ?? <>
                    Dieser Bereich ist nur für angemeldete Benutzer zugänglich. Bitte logge dich ein oder registriere dich.
                </>
            }


            <Group>
                <Button
                    variant={"light"}
                    leftSection={<IconX/>}
                    onClick={() => {
                        openHandler.close()
                        onAbort()
                    }}
                >
                    Abbrechen
                </Button>
                <Button
                    variant={"light"}
                    leftSection={<IconLogin/>}
                    onClick={() => {
                        loginHandler.open()
                        openHandler.close()
                    }}
                >
                    Login
                </Button>
            </Group>
        </div>
    </Modal>
}