import {useChangeEmail, useForgotPassword, useUserMenu} from "@/components/auth/modals/hooks.ts";
import {usePB} from "@/lib/pocketbase.tsx";
import {useShowHelp} from "@/components/ShowHelp.tsx";
import ShowDebug, {useShowDebug} from "@/components/ShowDebug.tsx";
import {ActionIcon, Code, Divider, Group, Modal, Switch, Text, ThemeIcon, Title, Tooltip} from "@mantine/core";
import classes from "@/components/layout/nav/index.module.css";
import {
    IconAt,
    IconCalendar,
    IconLogout,
    IconMailCog,
    IconPassword,
    IconServer,
    IconServerOff, IconUser
} from "@tabler/icons-react";
import LdapGroupsDisplay from "@/components/auth/LdapGroupsDisplay.tsx";

export default function UserMenuModal() {
    const {value, handler} = useUserMenu()

    const {handler: passwordResetHandler} = useForgotPassword()

    const {handler: changeEmailHandler} = useChangeEmail()

    const {logout, apiIsHealthy, user} = usePB()

    const {showHelp, toggleShowHelp} = useShowHelp()

    const {showDebug, toggleShowDebug} = useShowDebug()

    return <>
        <Modal opened={value && !!user} onClose={handler.close} withCloseButton={false} size={"md"}>
            <div className={classes.stack}>
                <Title order={3}>Hallo {user?.username}</Title>

                <ShowDebug>
                    Datenbank ID: <Code>{user?.id}</Code>

                    <br/>

                    REALM: <Code>{user?.REALM}</Code>

                    {user?.objectGUID && <>
                        <br/>
                        GUID: <Code>{user?.objectGUID}</Code>
                    </>}
                </ShowDebug>

                <div className={classes.row}>
                    <ThemeIcon
                        variant={"transparent"}
                        size={"xl"}
                    >
                        <IconUser/>
                    </ThemeIcon>


                        <Text>
                            {user?.REALM === "LDAP" ? "StuVe IT Account" : "Gast Account"}
                        </Text>
                </div>

                <div className={classes.row}>
                    <ThemeIcon
                        variant={"transparent"}
                        size={"xl"}
                    >
                        <IconAt/>
                    </ThemeIcon>


                    <Tooltip label={`Dein Email ist ${user?.emailVisibility ? "sichtbar" : "nicht sichtbar"}`}>
                        <Text>
                            {user?.email}
                        </Text>
                    </Tooltip>
                </div>

                <div className={classes.row}>
                    <ThemeIcon
                        variant={"transparent"}
                        size={"xl"}
                    >
                        <IconCalendar/>
                    </ThemeIcon>

                    <Text>
                        {user?.accountExpires ? (

                            new Date(user?.accountExpires).getTime() > Date.now() ? (
                                "Account ist aktiv und läuft am " + new Date(user?.accountExpires).toLocaleDateString() + " ab"
                            ) : (
                                "Account ist abgelaufen"
                            )
                        ) : (
                            "Dein Account läuft nicht ab"
                        )}
                    </Text>
                </div>

                <div className={classes.row}>
                    {apiIsHealthy ? (
                        <ThemeIcon
                            variant={"transparent"}
                            color={"green"}
                            size={"xl"}
                        >
                            <IconServer/>
                        </ThemeIcon>

                    ) : (
                        <ThemeIcon
                            variant={"transparent"}
                            color={"red"}
                            size={"xl"}
                        >
                            <IconServerOff/>
                        </ThemeIcon>
                    )}

                    <Text>
                        {apiIsHealthy ? "Das Backend ist erreichbar" : "Das Backend ist nicht erreichbar"}
                    </Text>
                </div>

                {(user?.memberOf?.length ?? 0) > 0 && <>
                    <Title order={5}>Deine Gruppen</Title>
                    <LdapGroupsDisplay groups={user?.expand?.memberOf}/>
                </>}

                <Divider label={"Einstellungen"}/>

                <Text c={"dimmed"} size={"xs"}>
                    Die folgenden Einstellungen werden lokal auf deinem Gerät gespeichert und nicht an den Server
                    übertragen.
                </Text>
                <Switch
                    checked={showHelp}
                    onChange={toggleShowHelp}
                    label={"Hilfe Fenster anzeigen"}
                />

                <Switch
                    checked={showDebug}
                    onChange={toggleShowDebug}
                    label={"Debug Modus aktivieren"}
                />

                <ShowDebug>
                    Der Debug Modus ändert nicht das Verhalten der Anwendung,
                    sondern zeigt zusätzliche Informationen an.
                </ShowDebug>

                <Divider
                    label={"Account"}
                />

                <Group justify={"center"}>
                    <Tooltip label={"Email ändern"}>
                        <ActionIcon
                            variant={"transparent"}
                            aria-label={"change email"}
                            onClick={() => {
                                handler.close()
                                changeEmailHandler.open()
                            }}
                        >
                            <IconMailCog/>
                        </ActionIcon>
                    </Tooltip>

                    <Tooltip label={"Passwort zurücksetzen"}>
                        <ActionIcon
                            variant={"transparent"}
                            aria-label={"change password"}
                            onClick={() => {
                                handler.close()
                                passwordResetHandler.open()
                            }}
                        >
                            <IconPassword/>
                        </ActionIcon>
                    </Tooltip>

                    <Tooltip label={"Ausloggen"}>
                        <ActionIcon
                            variant={"transparent"}
                            color={"orange"}
                            aria-label={"logout"}
                            onClick={() => {
                                logout()
                                handler.close()
                            }}
                        >
                            <IconLogout/>
                        </ActionIcon>
                    </Tooltip>
                </Group>
            </div>
        </Modal>
    </>
}