import {useSearchParams} from "react-router-dom";

export const useSearchParamToggle = (key: string) => {
    const [searchParams, setSearchParams] = useSearchParams()

    const value = searchParams.get(key) === "true"

     const open = () => {
        setSearchParams(prev => {
            const newParams = new URLSearchParams(prev);
            newParams.set(key, "true")
            return newParams
        }, { replace: true })
    }

    const close = () => {
        setSearchParams(prev => {
            const newParams = new URLSearchParams(prev);
            newParams.delete(key);
            return newParams;
        }, { replace: true })
    }

    return {
        value: value,
        handler: {
            open,
            close,
            toggle: () => value ? close() : open()
        }
    }
}

export const useLogin = () => useSearchParamToggle("login")

export const useRegister = () => useSearchParamToggle("register")

export const useUserMenu = () => useSearchParamToggle("userMenu")

export const useForgotPassword = () => useSearchParamToggle("forgotPassword")

export const useChangeEmail = () => useSearchParamToggle("changeEmail")