import {UserModal} from "@/models/AuthTypes.ts";
import {Tooltip} from "@mantine/core";

/**
 * Returns the username of a user
 * If the user has a first and last name, it will return the full name
 * @param user
 */
// eslint-disable-next-line react-refresh/only-export-components
export const getUserName = (user?: UserModal | null) => {
    if (!user) {
        return null
    }

    if (user.sn && user.givenName) {
        return `${user.givenName} ${user.sn}`
    }

    return user.username
}

/**
 * Renders the username with a tooltip indicating the account type
 * @param user
 * @constructor
 */
export const RenderUserName = ({user}: { user?: UserModal | null }) => {

    if (!user) {
        return null
    }

    return <>
        <Tooltip label={user.REALM === "LDAP" ? "StuVe IT Account" : "Gast Account"} withArrow>
            <span>
            {getUserName(user)}
            </span>
        </Tooltip>
    </>
}