export type AbstractFieldSchema = {
    id: string
    label: string
    description: string | null
    required: boolean
    placeholder: string | null
    meta?: {
        required?: boolean
        description?: string
    }
}

export type TextFieldSchema = {
    dataType: "text"
    multiline: boolean
    validator: {
        minLength: number | null
        maxLength: number | null
        regex: string
    }
} & AbstractFieldSchema

export type EmailFieldSchema = {
    dataType: "email",
    validator: {
        allowedDomains: string[],
    }
} & AbstractFieldSchema

export type NumberFieldSchema = {
    dataType: "number",
    validator: {
        min: number | null
        max: number | null
    }
} & AbstractFieldSchema

export type DateFieldSchema = {
    dataType: "date"
    validator: {
        minDate: Date | null
        maxDate: Date | null
    }
} & AbstractFieldSchema

export type DateRangeFieldSchema = {
    dataType: "date-range"
} & AbstractFieldSchema

export type SelectFieldSchema = {
    dataType: "select",
    multiple: boolean
    options: string[]
} & AbstractFieldSchema

export type CheckboxFieldSchema = {
    dataType: "checkbox"
} & AbstractFieldSchema

export type FormSchemaField =
    TextFieldSchema
    | EmailFieldSchema
    | NumberFieldSchema
    | DateFieldSchema
    | SelectFieldSchema
    | CheckboxFieldSchema
    | DateRangeFieldSchema

export type FieldDataType = FormSchemaField["dataType"]
export const FieldDataTypes: FieldDataType[] = ["text", "email", "number", "date", "date-range", "select", "checkbox"]

export type FormSchema = {
    fields: FormSchemaField[],
}