import {FieldEntries, FieldEntry} from "@/components/formUtil/FromInput/types.ts"
import {objectMap} from "@/lib/util.ts";
import {FormSchemaField} from "../formBuilder/types.ts";

export const renderEntries = (entries: FieldEntries, fields: FormSchemaField[]): {
    label: string,
    value: FieldEntry,
}[] => fields.map(field => ({
    label: field.label || field.id,
    value: entries[field.id]
}))


export const transformData = (d: FieldEntries) => objectMap(d, (_, entry) => {
    switch (entry.dataType) {
        case "date":
            return {
                dataType: "date",
                value: entry.value === null ? null : new Date(entry.value)
            } as FieldEntry
        case "date-range":
            return {
                dataType: "date-range",
                value: entry.value.some(v => v === null) ? [null, null] : [new Date(entry.value[0]!), new Date(entry.value[1]!)]
            } as FieldEntry
        case 'number':
            return {
                dataType: 'number',
                value: entry.value === null ? null : Number(entry.value)
            } as FieldEntry
        default:
            return entry
    }
})

