import {FieldDataType} from "../formBuilder/types.ts";
import {FieldEntryValue} from "@/components/formUtil/FromInput/types.ts";
import dayjs from "dayjs";

/**
 * This function sorts the cells based on their type and value
 * @param dataType
 * @param v1
 * @param v2
 */
export const sortCell = (dataType: FieldDataType, v1: FieldEntryValue, v2: FieldEntryValue): number => {
    if (typeof v1 !== typeof v2) return 0
    if (v1 === undefined || v1 === null || v1 === '') return -1
    if (v2 === undefined || v2 === null || v2 === '') return 1
    switch (dataType) {
        case "text":
        case "email":
            return (v1 as string).localeCompare(v2 as string)
        case "number":
            return (v1 as number) - (v2 as number)
        case "date":
            return dayjs(v1 as string).diff(v2 as string)
        case "date-range":
            return dayjs((v1 as string [])[0]).diff((v2 as string[])[0])
        case "checkbox":
            return v1 === v2 ? 0 : v1 ? 1 : -1
        case "select":
            return JSON.stringify(v1).localeCompare(JSON.stringify(v2))
        default:
            return 0
    }
}