import {FieldDataType, FormSchemaField} from "./formBuilder/types.ts";
import {nanoid} from "nanoid";

export const humanReadableField = (fieldType: FieldDataType): string => {
    switch (fieldType) {
        case "text":
            return "Text"
        case "email":
            return "Email"
        case "number":
            return "Zahl"
        case "date":
            return "Datum & Zeit"
        case "date-range":
            return "Zeit Bereich"
        case "select":
            return "(Mehrfach-) Auswahl"
        case "checkbox":
            return "Checkbox"
    }
}

export const createNewField = (fieldType: FieldDataType): FormSchemaField => {

    const abstractField = {
        id: nanoid(),
        label: "",
        description: "",
        placeholder: "",
        required: false,
        meta: {
            required: false
        }
    }

    switch (fieldType) {
        case "text":
            return {
                dataType: "text",
                multiline: false,
                validator: {
                    minLength: null,
                    maxLength: null,
                    regex: ""
                },
                ...abstractField,
            }
        case "email":
            return {
                dataType: "email",
                validator: {
                    allowedDomains: []
                },
                ...abstractField,
            }
        case "number":
            return {
                dataType: "number",
                validator: {
                    min: null,
                    max: null,
                },
                ...abstractField,
            }
        case "date":
            return {
                dataType: "date",
                validator: {
                    minDate: null,
                    maxDate: null,
                },
                ...abstractField,
            }
        case "date-range":
            return {
                dataType: "date-range",
                ...abstractField,
            }
        case "select":
            return {
                dataType: "select",
                multiple: false,
                options: [],
                ...abstractField,
            }
        case "checkbox":
            return {
                dataType: "checkbox",
                ...abstractField,
            }
    }
}