import classes from "./index.module.css";
import {APP_NAME, APP_VERSION} from "../../../../config.ts";
import {Anchor, Divider, Image} from "@mantine/core";
import {Link} from "react-router-dom";
import {usePB} from "@/lib/pocketbase.tsx";

export default function Footer() {
    const {apiIsHealthy} = usePB()
    return (
        <div className={classes.footer}>
            <div className={classes.inner}>
                <div className={classes.logo}>
                    <Image
                        h={15}
                        w={15}
                        src={"/stuve-logo.svg"}
                        alt={"StuVe IT Logo"}
                    />

                    <div className={classes.title}>{APP_NAME}</div>
                </div>

                <div className={`${classes.links} ${classes.hideMobile}`}>
                    <h5>Über</h5>

                    <p>Version {APP_VERSION}</p>

                    <p>Entwickelt vom StuVe Computer Referat</p>

                    <Anchor href={"https://git.stuve.uni-ulm.de/stuve-it/stuve-it-frontend"}>Source Code</Anchor>

                    <Anchor href={"https://git.stuve.uni-ulm.de/stuve-it/stuve-it-frontend/issues"}>Issues</Anchor>
                </div>

                <div className={`${classes.links} ${classes.hideMobile}`}>
                    <h5>Made with</h5>

                    <Anchor href={"https://mantine.dev/"}>Mantine</Anchor>

                    <Anchor href={"https://tanstack.com/"}>React Query</Anchor>

                    <Anchor href={"https://pocketbase.dev/"}>PocketBase</Anchor>

                    <Anchor
                        href={"https://git.stuve.uni-ulm.de/stuve-it/stuve-it-frontend/src/branch/main/package.json"}>...
                        and much more</Anchor>
                </div>

                {/* only these links will show on mobile */}
                <div className={classes.links}>
                    <h5 className={classes.hideMobile}>Rechtliches</h5>

                    <Link to={"/legal/terms-and-conditions"}>AGB der StuVe</Link>

                    <Link to={"/legal/privacy-policy"}>Datenschutzerklärung</Link>

                    <Link to={"/legal/imprint"}>Impressum</Link>
                </div>
            </div>

            <Divider/>
            <p className={classes.rights}>© 2024 {APP_NAME}. All rights reserved.
                {" "}
                <span data-apiishealthy={apiIsHealthy}>
                    {apiIsHealthy ? "Das Backend ist erreichbar." : "Das Backend ist nicht erreichbar!"}
                </span>
            </p>


        </div>
    )
}