import {usePB} from "@/lib/pocketbase.tsx";
import classes from "./index.module.css";
import {ActionIcon, Image, Menu, ThemeIcon, useMantineColorScheme} from "@mantine/core";
import {IconChevronDown, IconLogin, IconMoon, IconSun, IconUserStar} from "@tabler/icons-react";
import MenuItems from "./MenuItems.tsx";
import {useLogin, useUserMenu} from "@/components/auth/modals/hooks.ts";

export default function NavBar() {

    const {user} = usePB()

    const {colorScheme, toggleColorScheme} = useMantineColorScheme()

    const {handler: userMenuHandler} = useUserMenu()
    const {handler: loginHandler} = useLogin()

    return <nav className={classes.navbar}>
        <Menu
            trigger="hover"
            closeDelay={400}
            position="bottom-start"
            shadow="md"
            width={200}
        >
            <Menu.Target>
                <div className={classes.logo}>
                    <Image
                        h={30}
                        w={30}
                        src={"/stuve-logo.svg"}
                        alt={"StuVe IT Logo"}
                    />

                    <div className={classes.title}>
                        StuVe IT
                    </div>

                    <ThemeIcon variant={"transparent"} size={"sm"}>
                        <IconChevronDown/>
                    </ThemeIcon>
                </div>
            </Menu.Target>
            <Menu.Dropdown>
                <MenuItems/>
            </Menu.Dropdown>
        </Menu>

        <div className={classes.actionIcons}>
            <ActionIcon
                variant={"transparent"}
                color={"gray"}
                onClick={toggleColorScheme}
            >
                {colorScheme === "dark" ?
                    <IconSun/>
                    :
                    <IconMoon/>
                }
            </ActionIcon>

            {user ?
                <ActionIcon
                    variant={"transparent"}
                    color={"gray"}
                    aria-label={"User Menu"}
                    onClick={userMenuHandler.open}
                >
                    <IconUserStar/>
                </ActionIcon>
                : (
                    <ActionIcon
                        variant={"transparent"}
                        color={"gray"}
                        aria-label={"Login"}
                        onClick={loginHandler.open}
                    >
                        <IconLogin/>
                    </ActionIcon>
                )}
        </div>
    </nav>
}