import {usePB} from "./pocketbase.tsx";
import {useQuery} from "@tanstack/react-query";
import {TypedPocketBase} from "@/models";

type Setting = {
    value: string;
    description?: string;
    updated: Date
}

type Settings = {
    imprint: Setting
    privacyPolicy: Setting
    agb: Setting
    stexGroupId: Setting
    stuveEventQuestions: Setting
}

const loadSettings = async (pb: TypedPocketBase) => {
    const data = await pb.collection('settings').getFullList()
    return data.reduce((acc, s) => {
        acc[s.key as unknown as keyof Settings] = {
            value: s.value as string,
            description: s.description,
            updated: new Date(s.updated)
        }
        return acc
    }, {} as Settings)
}


export const useSettings = () => {
    const {pb} = usePB()

    const settingsQuery = useQuery({
        queryKey: ['settings'],
        queryFn: async () => await loadSettings(pb)
    })

    return settingsQuery.data
}