import {RecordModel} from "pocketbase";

export type UserModal = {
    username: string;
    verified: boolean;
    email: string;
    emailVisibility: boolean;
} & RecordModel & (GuestUser | LDAPUser)

type GuestUser = {
    REALM: "GUEST",

    cn: null;
    dn: null;
    sn: null;
    givenName: null;
    accountExpires: null;
    objectGUID: null;
    memberOf: [];
}

type LDAPUser = {
    REALM: "LDAP",

    cn: string;
    dn: string;
    sn: string;
    givenName: string;
    accountExpires: string | null;
    objectGUID: string;
    memberOf: string[];

    expand: {
        memberOf: LdapGroupModel[]
    }
}

export type LdapGroupModel = {
    description: string;
    cn: string;
    dn: string;
    objectGUID: string;
    memberOf: string[];

    expand: {
        memberOf: LdapGroupModel[]
    }
} & RecordModel

export type LdapSyncLogModel = {
    usersFound: number;
    usersSynced: number;
    usersRemoved: number;
    userSyncErrors: string[] | null;

    groupsFound: number;
    groupsSynced: number;
    groupsRemoved: number;
    groupSyncErrors: string[] | null;
} & RecordModel