import {UserModal} from "./AuthTypes.ts";
import {RecordModel} from "pocketbase";
import {FieldEntries} from "@/components/formUtil/FromInput/types.ts";
import {FormSchema} from "@/components/formUtil/formBuilder/types.ts";

export type EventModel = {
    name: string;
    description: string | null;
    startDate: string;
    endDate: string;
    eventAdmins: string[];
    eventListAdmins: string[];
    img: string | null; // png, jpg, gif
    location: string | null;
    isStuveEvent: boolean;
    additionalAgb: string | null;
    hideFromPublic: boolean;
    eventLinks: EventLink[];
    defaultEntryQuestionSchema: FormSchema | null;
    defaultEntryStatusSchema: FormSchema | null;
    expand?: {
        eventAdmins: UserModal[] | null;
        eventListAdmins: UserModal[] | null;
    }
} & RecordModel

export type EventLink = {
    name: string;
    url: string;
}

export type EventListModel = {
    name: string;
    description: string | null;
    open: boolean | null;
    favourite: boolean | null;
    allowOverlappingEntries: boolean | null;
    onlyStuVeAccounts: boolean | null;
    event: string
    entryQuestionSchema: FormSchema | null
    entryStatusSchema: FormSchema | null;
    expand?: {
        event: EventModel;
    }
} & RecordModel


export type EventListSlotModel = {
    eventList: string;
    startDate: string;
    endDate: string;
    maxEntries: number | null;
    description: string | null;
    expand?: {
        eventList: EventListModel;
    }
} & RecordModel

export type EventListSlotsWithEntriesCountModel = EventListSlotModel
    & { entriesCount: number }
    & Pick<EventModel, "defaultEntryQuestionSchema" | "defaultEntryStatusSchema">
    & Pick<EventListModel, "entryQuestionSchema" | "entryStatusSchema">

export type EventListSlotEntryModel = {
    entryQuestionData: FieldEntries;
    entryStatusData: FieldEntries | null;
    eventListsSlot: string;
    user: string | null
    expand?: {
        eventListsSlot: EventListSlotModel;
        user: UserModal | null;
    }
} & RecordModel

export type EventListSlotEntriesWithUserModel =
    EventListSlotEntryModel
    & {
    user: string;
    listName: string,
    slotStartDate: string,
    slotEndDate: string,
    slotDescription: string | null,
    eventList: string,
    listDescription: string | null,
    event: string,
    eventName: string,
    expand?: {
        event: EventModel;
        eventList: EventListModel;
        user: UserModal;
    }
}
    & Pick<EventModel, "defaultEntryQuestionSchema" | "defaultEntryStatusSchema">
    & Pick<EventListModel, "entryQuestionSchema" | "entryStatusSchema">