import {LoadingOverlay} from "@mantine/core";
import InnerHtml from "@/components/InnerHtml";
import {pprintDate} from "@/lib/datetime.ts";
import {useParams} from "react-router-dom";
import {useQuery} from "@tanstack/react-query";
import {usePB} from "@/lib/pocketbase.tsx";
import NotFound from "@/pages/not-found/index.page.tsx";

export default function LegalPage() {
    const {page} = useParams() as { page: string }

    const {pb} = usePB()

    const query = useQuery({
        queryKey: ["legalSettings", page],
        queryFn: async () => await pb.collection("legalSettings").getFirstListItem(`name='${page}'`),
        enabled: !!page
    })

    if (query.isPending) return <LoadingOverlay visible={true}/>

    if (query.isError || !query.data) return <NotFound/>

    return <>
        <div className={"section"}>
            Zuletzt Bearbeitet: {pprintDate(query.data.updated)}
        </div>

        <div className={"section"}>
            <InnerHtml html={query.data.legalText}/>
        </div>
    </>
}