import {IconConfetti, IconPlus, IconUser} from "@tabler/icons-react";
import {EventCalendar} from "./EventCalendar.tsx";
import {EventList} from "./EventList.tsx";
import {Anchor, Breadcrumbs, Button, Collapse} from "@mantine/core";
import {usePB} from "@/lib/pocketbase.tsx";
import {useDisclosure} from "@mantine/hooks";
import CreateEvent from "./CreateEvent.tsx";
import {Link, useNavigate} from "react-router-dom";


export default function EventOverview() {

    const {user} = usePB()
    const [showCreateEvent, showCreateEventHandler] = useDisclosure(false)
    const navigate = useNavigate();

    return <>
        <div className={"section-transparent"}>
            <Breadcrumbs>{
                [{title: "Home", to: "/"}, {title: "Events", to: "/events"},
                ].map(({title, to}) => (
                    <Anchor component={Link} to={to} key={title}>{title}</Anchor>
                ))
            }</Breadcrumbs>
        </div>

        <div className={"section"}>
            <div className={"section-icon"}><IconConfetti/></div>
            <h1>Events</h1>
        </div>

        {
            (user) && <>
                <Collapse in={showCreateEvent} className={"section"}>
                    <CreateEvent
                        onAbort={showCreateEventHandler.close}
                        onSuccess={(event) => navigate(`/events/e/${event.id}/settings`)}
                    />
                </Collapse>

                {!showCreateEvent && <div className={"section-transparent group"} style={{gap: 0}}>
                    <Button
                        leftSection={<IconUser/>}
                        variant={"transparent"}
                        color={"green"}
                        component={Link}
                        to={"/events/entries"}
                    >
                        Deine Anmeldungen bei Events
                    </Button>
                    <Button
                        leftSection={<IconPlus/>}
                        variant={"transparent"}
                        onClick={showCreateEventHandler.toggle}
                        color={"green"}
                    >
                        Neues Event erstellen
                    </Button>
                </div>}
            </>
        }

        <div className={"section"}>
            <EventCalendar/>
        </div>

        <div className={"section"}>
            <EventList/>
        </div>
    </>
}