import {Alert, Button, Title} from "@mantine/core";
import {Link} from "react-router-dom";
import InnerHtml from "@/components/InnerHtml";
import {EventModel} from "@/models/EventTypes.ts";
import {IconQuestionMark} from "@tabler/icons-react";

/**
 * Displays the AGBs of an event
 * If the event is a StuVe event, the StuVe AGBs are displayed
 * If the event has additional AGBs, they are displayed
 * If the event has neither, a message is displayed
 * @param event The event to display the AGBs for
 */
export default function EventAGB({event}: { event: EventModel }) {

    if (!event.isStuveEvent && !event.additionalAgb) {
        return <Alert
            icon={<IconQuestionMark/>}
            title={"Keine AGBs vorhanden"}
            color={"orange"}
            children={"Dieses Event hat keine AGBs."}
        />
    }

    return <>
        {
            event.isStuveEvent && (
                <Alert color={"green"} className={"section-transparent"} p={"sm"}>
                    <Title order={2}>StuVe Event</Title>
                    Diese Veranstaltung wird von der Studierendenschaft der Universität Ulm organisiert.
                    <br/>
                    Es gelten immer die AGBs der Studierendenschaft der Universität Ulm.
                    <br/>
                    <Button
                        mt={"sm"}
                        variant={"light"}
                        component={Link} to={"/legal/terms-and-conditions"} target={"_blank"}
                    >
                        AGB der StuVe
                    </Button>
                </Alert>
            )
        }

        {
            event.additionalAgb && (
                <Alert className={"section-transparent"} p={"sm"}>
                    <Title order={2}>Event AGB's</Title>
                    <InnerHtml html={event.additionalAgb}/>
                </Alert>
            )
        }
    </>
}