import {EventModel} from "@/models/EventTypes.ts";
import classes from "../EditEventRouter.module.css";
import {IconAdjustments, IconCalendar, IconHourglass, IconList, IconMap, IconSparkles} from "@tabler/icons-react";
import {areDatesSame, humanDeltaFromNow, pprintDate} from "@/lib/datetime.ts";
import UsersDisplay from "@/components/auth/UsersDisplay.tsx";
import {Text, ThemeIcon, Title} from "@mantine/core";

/**
 * Displays the event data
 *  - Whether it is a StuVe event
 *  - The location
 *  - The time delta from now
 *  - The start and end date
 *  - The admin members
 * @param event The event to display
 * @param hideHeader Whether to hide the title
 */

export default function EventData({event, hideHeader}: { event: EventModel, hideHeader?: boolean }) {

    const delta = humanDeltaFromNow(event.startDate, event.endDate)

    return (
        <div className={`section`}>

            {!hideHeader && <Title order={2}>Event Übersicht</Title>}

            <div className={classes.data}>
                {
                    event.isStuveEvent && <>
                        <div className={"group"}>
                            <ThemeIcon variant={"transparent"} color={"indigo"} size={"xs"}>
                                <IconSparkles size={16}/>
                            </ThemeIcon>
                            <Text
                                w={"calc(100% - 30px)"}
                                truncate={"end"}
                                fw={600}
                                c={"indigo"}
                            >
                                StuVe Event
                            </Text>
                        </div>
                    </>
                }

                <div className={"group"}>
                    <IconMap size={16}/>
                    <Text
                        w={"calc(100% - 30px)"}
                        truncate={"end"}
                        c={!event.location ? "red" : undefined}
                    >
                        {event.location || "Kein Ort angegeben"}
                    </Text>
                </div>

                <div className={"group"}>
                    <IconHourglass size={16}/>
                    <Text
                        w={"calc(100% - 30px)"}
                        truncate={"end"}
                    >
                        {delta.message}
                    </Text>
                </div>

                <div className={"group"}>
                    <IconCalendar size={16}/>
                    <Text
                        w={"calc(100% - 30px)"}
                        truncate={"end"}
                    >
                        {areDatesSame(event.startDate, event.endDate) ?
                            pprintDate(event.startDate)
                            :
                            `${pprintDate(event.startDate)} - ${pprintDate(event.endDate)}`
                        }
                    </Text>
                </div>

                {
                    event.expand?.eventAdmins &&
                    <div className={classes.stack}>
                        <div className={"group"}>
                            <IconAdjustments size={16}/>
                            Event Admins
                        </div>
                        <UsersDisplay users={event.expand.eventAdmins}/>
                    </div>
                }

                {
                    event.expand?.eventListAdmins &&
                    <div className={classes.stack}>
                        <div className={"group"}>
                            <IconList size={16}/>
                            Listen Admins
                        </div>
                        <UsersDisplay users={event.expand.eventListAdmins}/>
                    </div>
                }
            </div>
        </div>
    )
}