import {EventListModel, EventModel} from "@/models/EventTypes.ts";
import {useQuery} from "@tanstack/react-query";
import {usePB} from "@/lib/pocketbase.tsx";
import {Anchor, List} from "@mantine/core";
import {IconStar} from "@tabler/icons-react";
import {NavLink} from "react-router-dom";

/**
 * Loads and displays all lists that have the event as a favourite, if any.
 * @param event The event to display the favourites for.
 */
export default function EventFavourites({event}: { event: EventModel }) {

    const {pb} = usePB()

    const favoriteListsQuery = useQuery({
        queryKey: ["event", event.id, "favorites"],
        queryFn: async () => await pb.collection("eventLists").getFullList({
            filter: `event='${event.id}' && favorite=true`,
        })
    })

    if (!favoriteListsQuery.data || favoriteListsQuery.data.length === 0) return null

    return (
        <div className={"section"}>
            <List>
                {favoriteListsQuery.data.map((list: EventListModel) => (
                    <NavLink to={`/events/e/${event.id}/lists/overview/${list.id}`} key={list.id}>
                        {({isActive}) => (
                            <List.Item icon={<IconStar size={10}/>}>
                                <Anchor component={"span"} fw={isActive ? 600 : undefined}>
                                    {list.name}
                                </Anchor>
                            </List.Item>
                        )}
                    </NavLink>
                ))}
            </List>
        </div>
    )
}