import {EventModel} from "@/models/EventTypes.ts";
import {Anchor, List} from "@mantine/core";
import {IconLink} from "@tabler/icons-react";

/**
 * Renders a list of links for an event, if any.
 * @param event The event to render links for.
 */
export default function EventLinks({event}: { event: EventModel }) {

    if (event.eventLinks?.length === 0 || !event.eventLinks) {
        return null;
    }

    return (
        <div className={`section`}>
            <List>
                {(event.eventLinks ?? []).map((link, index) => (
                    <List.Item icon={<IconLink size={10}/>} key={index}>
                        <Anchor
                            c={"blue"}
                            href={link.url} key={index}
                            target={"_blank"}
                            rel={"noopener noreferrer"}
                            w={"calc(100% - 30px)"}
                            truncate={"end"}
                        >
                            {link.name}
                        </Anchor>
                    </List.Item>
                ))}
            </List>
        </div>
    )
}