import {EventModel} from "@/models/EventTypes.ts";
import {PocketBaseErrorAlert, usePB} from "@/lib/pocketbase.tsx";
import {Alert, Button, Group, Title} from "@mantine/core";
import {useMutation} from "@tanstack/react-query";
import {queryClient} from "@/main.tsx";
import {IconArchive} from "@tabler/icons-react";
import {useConfirmModal} from "@/components/ConfirmModal.tsx";
import {showSuccessNotification} from "@/components/util.tsx";

/**
 * This component lets the user archive an event.
 * The event will still be visible but not editable.
 * @param event The event to archive
 */
export default function ArchiveEvent({event}: { event: EventModel }) {

    const {pb} = usePB()

    const editMutation = useMutation({
        mutationFn: async () => {
            return await pb.collection("events").update(event.id, {
                eventAdmins: []
            })
        },
        onSuccess: () => {
            showSuccessNotification("Event archiviert")
            return queryClient.invalidateQueries({queryKey: ["event", event.id]})
        }
    })

    const {ConfirmModal, toggleConfirmModal} = useConfirmModal({
        description: "Willst Du dieses Ereignis wirklich archivieren?",
        onConfirm: () => editMutation.mutate()
    })

    return <>
        <ConfirmModal/>

        <Title order={4} c={"red"}>Event Archivieren</Title>

        <PocketBaseErrorAlert error={editMutation.error}/>

        <Alert color={"red"}>
            Wenn Du dieses Ereignis archivierst, kann es weiterhin gesehen, jedoch nicht mehr bearbeitet
            werden.
            <br/>
            Nur ein Systemadministrator (C-Ref) kann diese Aktion rückgängig machen.
        </Alert>

        <Group>
            <Button
                color={"red"}
                onClick={toggleConfirmModal}
                loading={editMutation.isPending}
                leftSection={<IconArchive/>}
            >
                Archivieren
            </Button>
        </Group>
    </>
}