import {EventListModel, EventModel} from "@/models/EventTypes.ts";
import {PocketBaseErrorAlert, usePB} from "@/lib/pocketbase.tsx";
import {useMutation} from "@tanstack/react-query";
import {showSuccessNotification} from "@/components/util.tsx";
import {queryClient} from "@/main.tsx";
import {Alert, Text, Title} from "@mantine/core";
import {FormSchema} from "@/components/formUtil/formBuilder/types.ts";
import FormBuilder from "@/components/formUtil/formBuilder";
import FormFieldsPreview from "@/components/formUtil/formBuilder/FormFieldsPreview.tsx";
import {IconAlertTriangle} from "@tabler/icons-react";

export default function EventListEntryStatusSettings({list, event}: { list: EventListModel, event: EventModel }) {
    const {pb} = usePB()

    const editMutation = useMutation({
        mutationFn: async (schema: FormSchema) => {
            return await pb.collection("eventLists").update(list.id, {
                entryStatusSchema: schema
            })
        },
        onSuccess: () => {
            showSuccessNotification("Status Felder gespeichert")
            return queryClient.invalidateQueries({queryKey: ["event", event.id, "list", list.id]})
        }
    })

    return <div className={"section stack"}>
        <Title order={4} c={"blue"}>Eintrags-Status der Liste</Title>

        <PocketBaseErrorAlert error={editMutation.error}/>

        {event.defaultEntryStatusSchema && (
            <Alert color={"blue"} title={"Standard Status Felder"} className={"stack"}>
                <Text c={"dimmed"} mb={"sm"} size={"xs"}>
                    Folgende Status-Felder sind standardmäßig für dieses Event vorgesehen
                    und werden automatisch angehängt:
                </Text>
                <FormFieldsPreview formSchema={event.defaultEntryStatusSchema ?? {fields: []}}/>
            </Alert>
        )}

        <Alert color={"orange"} icon={<IconAlertTriangle/>}>
            Wenn du Felder entfernst, werden alle Daten,
            die für diese Felder gespeichert wurden nicht mehr angezeigt.
        </Alert>

        <FormBuilder
            defaultValue={list.entryStatusSchema || {fields: []}}
            onSubmit={(schema) => editMutation.mutate(schema)}
            withPreview
            additionalSchemaToPreview={event.defaultEntryStatusSchema || {fields: []}}
        />
    </div>
}