import {
    EventListModel,
    EventListSlotEntriesWithUserModel,
    EventListSlotModel,
    EventModel
} from "@/models/EventTypes.ts";
import {useDisclosure} from "@mantine/hooks";
import classes from "./EventListSlotEntryRow.module.css";
import {ActionIcon, Box, Collapse, Group, SimpleGrid, Tooltip} from "@mantine/core";
import {IconCheckupList, IconForms, IconUserMinus, IconUserPlus} from "@tabler/icons-react";
import {renderEntries} from "@/components/formUtil/formTable";
import RenderCell from "@/components/formUtil/formTable/RenderCell.tsx";
import EditSlotEntryMenu from "@/pages/events/e/:eventId/EventLists/components/EditSlotEntryMenu.tsx";
import {RenderUserName} from "@/components/auth/modals/util.tsx";


export const EventListSlotEntryDetails = ({entry}: {
    entry: EventListSlotEntriesWithUserModel
}) => {
    const questionSchemaFields = [
        ...entry.entryQuestionSchema?.fields ?? [],
        ...entry.defaultEntryQuestionSchema?.fields ?? [],
    ]

    const statusSchemaFields = [
        ...entry.entryStatusSchema?.fields ?? [],
        ...entry.defaultEntryStatusSchema?.fields ?? [],
    ]

    return <>
        <SimpleGrid className={classes.dataGrid} cols={{base: 2, sm: 3, lg: 4}}>
            {renderEntries(entry.entryQuestionData ?? {}, questionSchemaFields).map(({label, value}) => {
                return <div className={classes.dataCell} key={label}>
                    <div className={classes.dataIcon}>
                        <IconForms size={16}/>
                    </div>

                    <div className={classes.dataTitle}>
                        {label}
                    </div>
                    <Box>
                        <RenderCell entry={value}/>
                    </Box>
                </div>
            })}

            {renderEntries(entry.entryStatusData ?? {}, statusSchemaFields).map(({label, value}) => {
                return <div className={classes.dataCell} key={label}>
                    <div className={classes.dataIcon}>
                        <IconCheckupList size={16}/>
                    </div>

                    <div className={classes.dataTitle}>
                        {label}
                    </div>
                    <Box>
                        <RenderCell entry={value}/>
                    </Box>
                </div>
            })}
        </SimpleGrid>
    </>
}

/**
 * Renders a row with all entries for a slot
 * @param entry - entry to render
 * @param slot - slot the entry belongs to
 * @param list - list the entry belongs to
 * @param event - event the entry belongs to
 * @param refetch - refetch function for the entries
 * @constructor
 */
export const EventListSlotEntryRow = ({entry, refetch}: {
    entry: EventListSlotEntriesWithUserModel,
    slot: EventListSlotModel,
    list: EventListModel,
    event: EventModel,
    refetch: () => void
}) => {
    const [expanded, expandedHandler] = useDisclosure(false)
    return <div className={classes.entryContainer} aria-expanded={expanded}>
        <div className={classes.entryRow}>
            <Tooltip label={"Details anzeigen"} withArrow>
                <ActionIcon variant={"transparent"} onClick={expandedHandler.toggle}>
                    {expanded ? <IconUserMinus size={16}/> : <IconUserPlus size={16}/>}
                </ActionIcon>
            </Tooltip>

            <div><RenderUserName user={entry.expand?.user}/></div>

            <Group gap={4} justify="right" wrap="nowrap">
                <EditSlotEntryMenu entry={entry} refetch={refetch}/>
            </Group>
        </div>

        <Collapse in={expanded}>
            <EventListSlotEntryDetails entry={entry}/>
        </Collapse>
    </div>
}