import {EventListModel, EventListSlotsWithEntriesCountModel, EventModel} from "@/models/EventTypes.ts";
import {useDisclosure} from "@mantine/hooks";
import classes from "./EventListSlotRow.module.css";
import {ActionIcon, Alert, Code, Collapse, Group, Modal, ThemeIcon} from "@mantine/core";
import {IconAdjustments, IconAdjustmentsOff, IconInfoCircle, IconUsersMinus, IconUsersPlus} from "@tabler/icons-react";
import {RenderDateRange} from "../../components/RenderDateRange.tsx";
import {modals} from "@mantine/modals";
import InnerHtml from "@/components/InnerHtml";
import {EventListSlotEntriesTable} from "./EventListSlotEntriesTable.tsx";
import UpsertEventListSlot from "@/pages/events/e/:eventId/EventLists/components/UpsertEventListSlot.tsx";
import EventListSlotProgress from "@/pages/events/e/:eventId/EventLists/components/EventListSlotProgress.tsx";
import ShowDebug from "@/components/ShowDebug.tsx";

export const EventListSlotRow = ({slot, list, event, refetch}: {
    slot: EventListSlotsWithEntriesCountModel,
    list: EventListModel,
    event: EventModel,
    refetch: () => void
}) => {

    const [showEditModal, showEditModalHandler] = useDisclosure(false)

    const [expanded, expandedHandler] = useDisclosure(false)

    return (
        <div className={`${classes.slotContainer}`}>
            <Modal
                opened={showEditModal} onClose={showEditModalHandler.close}
                title={`Zeitslot bearbeiten`}
                size={"lg"}
            >
                <UpsertEventListSlot slot={slot} list={list} onSuccess={() => {
                    showEditModalHandler.close()
                    refetch()
                }} onAbort={showEditModalHandler.close}/>
            </Modal>
            <div
                className={classes.slotRow}
                onClick={expandedHandler.toggle}
            >
                <ThemeIcon variant={"transparent"}>
                    {
                        expanded ? <IconUsersMinus size={16}/> : <IconUsersPlus size={16}/>
                    }
                </ThemeIcon>
                <RenderDateRange start={new Date(slot.startDate)} end={new Date(slot.endDate)}/>
                <EventListSlotProgress slot={slot}/>
                <Group gap={4} justify="right" wrap="nowrap">
                    <ActionIcon
                        size="sm"
                        variant="subtle"
                        color="blue"
                        onClick={(e) => {
                            e.stopPropagation()
                            showEditModalHandler.toggle()
                        }}
                    >
                        {showEditModal ? <IconAdjustmentsOff size={16}/> : <IconAdjustments size={16}/>}
                    </ActionIcon>
                    <ActionIcon
                        size="sm"
                        variant="subtle"
                        color="blue"
                        onClick={(e) => {
                            e.stopPropagation()
                            modals.open({
                                title: 'Beschreibung',
                                children: <div className={"stack"}>
                                    <ShowDebug>
                                        Listen-ID <Code>{list.id}</Code>
                                        <br/>
                                        Slot-ID <Code>{slot.id}</Code>
                                    </ShowDebug>
                                    {
                                        slot.description ? <InnerHtml html={slot.description}/> :
                                            <Alert color={"orange"}>
                                                Keine Beschreibung vorhanden
                                            </Alert>
                                    }
                                </div>
                            })
                        }}
                    >
                        <IconInfoCircle size={16}/>
                    </ActionIcon>
                </Group>
            </div>

            <Collapse in={expanded}>
                <EventListSlotEntriesTable visible={expanded} slot={slot} list={list} refetch={refetch} event={event}/>
            </Collapse>
        </div>
    )
}