import {EventListSlotEntriesWithUserModel} from "@/models/EventTypes.ts";
import classes from "./EventListSearchResult.module.css";
import {ActionIcon, Collapse, ThemeIcon, Tooltip} from "@mantine/core";
import {IconChevronDown, IconChevronRight, IconList, IconUser} from "@tabler/icons-react";
import TextWithIcon from "@/components/layout/TextWithIcon";
import {
    EventListSlotEntryDetails
} from "@/pages/events/e/:eventId/EventLists/:listId/EventListSlotsTable/EventListSlotEntryRow.tsx";

import {useDisclosure} from "@mantine/hooks";
import {RenderDateRange} from "@/pages/events/e/:eventId/EventLists/components/RenderDateRange.tsx";
import EditSlotEntryMenu from "@/pages/events/e/:eventId/EventLists/components/EditSlotEntryMenu.tsx";
import {RenderUserName} from "@/components/auth/modals/util.tsx";

export default function EventListSearchResult({entry, refetch}: {
    entry: EventListSlotEntriesWithUserModel,
    refetch: () => void
}) {

    const [expanded, expandedHandler] = useDisclosure(false)

    return <div className={classes.container}>

        <div className={classes.row}>
            <Tooltip label={expanded ? "Details verbergen" : "Details anzeigen"} withArrow>
                <ActionIcon onClick={expandedHandler.toggle} variant={"light"} size={"xs"}>
                    {expanded ? <IconChevronDown/> : <IconChevronRight/>}
                </ActionIcon>
            </Tooltip>

            <TextWithIcon icon={
                <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                    <IconUser/>
                </ThemeIcon>
            }>
                <RenderUserName user={entry.expand?.user}/>
            </TextWithIcon>

            <TextWithIcon icon={
                <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                    <IconList/>
                </ThemeIcon>
            }>
                {entry.listName}
            </TextWithIcon>

            <RenderDateRange start={new Date(entry.slotStartDate)} end={new Date(entry.slotEndDate)}/>

            <EditSlotEntryMenu entry={entry} refetch={refetch}/>
        </div>

        <Collapse in={expanded}>
            <EventListSlotEntryDetails entry={entry}/>
        </Collapse>
    </div>
}