import {EventListModel, EventModel} from "@/models/EventTypes.ts";
import {Button, CopyButton, Group, Title, Tooltip} from "@mantine/core";
import {useState} from "react";
import ListSelect from "@/pages/events/e/:eventId/EventLists/ListSelect.tsx";
import ShowHelp from "@/components/ShowHelp.tsx";
import {IconClipboard, IconClipboardCheck, IconExternalLink, IconQrcode} from "@tabler/icons-react";
import {APP_URL} from "../../../../../../config.ts";
import {Link} from "react-router-dom";


export default function EventListShare({event}: { event: EventModel }) {

    const [selectedLists, setSelectedLists] = useState<EventListModel[]>([])

    const path = `/events/s/${event.id}?lists=${selectedLists.map(l => l.id).join(",")}`
    const link = `${APP_URL}${path}`

    return <div className={"stack"}>
        <Title order={4} c={"blue"}>Listen Teilen</Title>

        <ShowHelp>
            Wähle Listen aus, die du teilen möchtest. Die ausgewählten Listen können dann über den generierten
            Link geteilt werden.
        </ShowHelp>

        <div className={"section stack"}>
            <Title order={5} c={"blue"}>Link Generator</Title>

            <ListSelect
                event={event}
                selectedRecords={selectedLists}
                setSelectedRecords={setSelectedLists}
                placeholder={"Listen zum Teilen auswählen ..."}
            />

            <Group>
                <CopyButton value={link}>
                    {({copied, copy}) => (
                        <Tooltip label={"Link in die Zwischenablage kopieren"} withArrow>
                            <Button
                                color={copied ? 'teal' : 'blue'}
                                onClick={copy}
                                disabled={selectedLists.length === 0}
                                leftSection={copied ? <IconClipboardCheck/> : <IconClipboard/>}
                            >
                                {'Link kopieren'}
                            </Button>
                        </Tooltip>
                    )}
                </CopyButton>

                <Tooltip label={"QR Code für den Link"} withArrow>
                    <Button
                        leftSection={<IconQrcode/>}
                        component={Link}
                        to={`/util/qr?data=${encodeURIComponent(link)}`}
                        target={"_blank"}
                        disabled={selectedLists.length === 0}
                    >
                        QR Code
                    </Button>
                </Tooltip>

                <Tooltip label={"Link in neuem Tab öffnen"} withArrow>
                    <Button
                        leftSection={<IconExternalLink/>}
                        component={Link}
                        to={path}
                        target={"_blank"}
                        disabled={selectedLists.length === 0}
                    >
                        Listen Teilen
                    </Button>
                </Tooltip>
            </Group>
        </div>
    </div>
}