import {EventModel} from "@/models/EventTypes.ts";
import {Navigate, NavLink, Route, Routes} from "react-router-dom";
import EventListsOverview from "./EventListsOverview.tsx";
import EventListRouter from "./:listId/EventListRouter.tsx";
import {IconCheckupList, IconForms, IconLink, IconList, IconUserSearch} from "@tabler/icons-react";
import {ReactNode} from "react";
import {Menu} from "@mantine/core";
import EventListSearch from "./EventListSearch/index.tsx";
import EventListShare from "@/pages/events/e/:eventId/EventLists/EventListShare.tsx";
import EditEventDefaultEntryStatusSchema
    from "@/pages/events/e/:eventId/EventLists/EventListSettings/EditEventDefaultEntryStatusSchema.tsx";
import EditEventDefaultEntryQuestionSchema
    from "@/pages/events/e/:eventId/EventLists/EventListSettings/EditEventDefaultEntryQuestionSchema.tsx";


const nav = [
    {
        label: "Listenaktionen",
        children: [
            {
                title: "Übersicht",
                icon: <IconList size={16}/>,
                to: "overview"
            },
            {
                title: "Durchsuchen",
                icon: <IconUserSearch size={16}/>,
                to: "search"
            },
            {
                title: "Teilen",
                icon: <IconLink size={16}/>,
                to: "share"
            }
        ]
    },
    {
        label: "Einstellungen",
        children: [
            {
                title: "Formulare",
                icon: <IconForms size={16}/>,
                to: "e/questions"
            },
            {
                title: "Status-Felder",
                icon: <IconCheckupList size={16}/>,
                to: "e/status"
            }
        ]
    },
]

/**
 * Dropdown menu to navigate between different settings of an event
 * @param event - the event to edit
 * @param target - the trigger element for the dropdown
 */
export const EventListsMenu = ({event, target}: { event: EventModel, target: ReactNode }) => {
    return <>
        <Menu
            withArrow shadow="md" width={200} trigger="click-hover" loop={false}
            withinPortal={false} trapFocus={false} menuItemTabIndex={0}
        >
            <Menu.Target>
                {target}
            </Menu.Target>

            <Menu.Dropdown>
                {
                    nav.map(({label, children,}, index, array) => <div key={index}>
                        <Menu.Label>{label}</Menu.Label>
                        {children.map(({title, icon, to}) => (
                            <NavLink to={`/events/e/${event.id}/lists/${to}`} key={to}>
                                {({isActive}) => (
                                    <Menu.Item color={isActive ? "blue" : undefined} leftSection={icon}>
                                        {title}
                                    </Menu.Item>
                                )}
                            </NavLink>
                        ))}
                        {index !== array.length - 1 && <Menu.Divider/>}
                    </div>)
                }
            </Menu.Dropdown>
        </Menu>
    </>
}

export default function EventListsRouter({event}: { event: EventModel }) {

    return <>
        <Routes>
            <Route index element={<Navigate to={"overview"} replace/>}/>

            <Route path={"search"} element={<EventListSearch event={event}/>}/>
            <Route path={"share"} element={<EventListShare event={event}/>}/>

            <Route path={"e/status"} element={<EditEventDefaultEntryStatusSchema event={event}/>}/>
            <Route path={"e/questions"} element={<EditEventDefaultEntryQuestionSchema event={event}/>}/>

            <Route path={"overview"} element={<EventListsOverview event={event}/>}/>
            <Route path={"overview/:listId/*"} element={<EventListRouter event={event}/>}/>
        </Routes>
    </>
}