import {useMutation} from "@tanstack/react-query";
import {IconListSearch} from "@tabler/icons-react";
import {usePB} from "@/lib/pocketbase.tsx";
import {EventListModel, EventModel} from "@/models/EventTypes.ts";
import RecordSearchInput, {GenericRecordSearchInputProps} from "@/components/input/RecordSearchInput.tsx";


export default function ListSelect(props: GenericRecordSearchInputProps<EventListModel> & { event?: EventModel }) {

    const {pb} = usePB()

    return (
        <RecordSearchInput
            <EventListModel>
            recordToString={(record) => ({displayName: record.name})}
            placeholder={props.placeholder || "Suche nach Listen..."}
            {...props}
            leftSection={<IconListSearch size={18}/>}
            recordSearchMutation={
                useMutation({
                    mutationFn: async (search: string) => {

                        const filter: string[] = []

                        if (search) {
                            filter.push(`name ~ "${search}"`)
                        }

                        if (props.event) {
                            filter.push(`event='${props.event.id}'`)
                        }

                        return (await pb.collection('eventLists').getList(1, 5, {
                            filter: filter.join(" && "),
                        })).items
                    }
                })
            }
        />
    )
}

