import {EventListSlotEntriesWithUserModel} from "@/models/EventTypes.ts";
import {useMutation} from "@tanstack/react-query";
import {showSuccessNotification} from "@/components/util.tsx";
import {useConfirmModal} from "@/components/ConfirmModal.tsx";
import {usePB} from "@/lib/pocketbase.tsx";
import {useDisclosure} from "@mantine/hooks";
import {
    UpdateEventListSlotEntryStatusModal
} from "@/pages/events/e/:eventId/EventLists/components/UpdateEventListSlotEntryStatusModal.tsx";
import {
    MoveEventListSlotEntryModal
} from "@/pages/events/e/:eventId/EventLists/components/MoveEventListSlotEntryModal.tsx";
import {
    UpdateEventListSlotEntryFormModal
} from "@/pages/events/e/:eventId/EventLists/components/UpdateEventListSlotEntryFormModal.tsx";
import {ActionIcon, Button, Menu} from "@mantine/core";
import {IconArrowsMove, IconCheckupList, IconForms, IconSettings, IconTrash} from "@tabler/icons-react";
import {getUserName} from "@/components/auth/modals/util.tsx";

export default function EditSlotEntryMenu({entry, refetch}: {
    refetch: () => void,
    entry: EventListSlotEntriesWithUserModel
}) {

    const {pb} = usePB()

    const [showStatusEditModal, showStatusEditModalHandler] = useDisclosure(false)

    const [showMoveEntryModal, showMoveEntryModalHandler] = useDisclosure(false)

    const [showEditFormModal, showEditFormModalHandler] = useDisclosure(false)

    const deleteEntryMutation = useMutation({
        mutationFn: async () => {
            await pb.collection("eventListSlotEntries").delete(entry.id)
        },
        onSuccess: () => {
            refetch()
            showSuccessNotification("Eintrag gelöscht")
        }
    })

    const {ConfirmModal, toggleConfirmModal} = useConfirmModal({
        title: 'Eintrag löschen',
        description: `Möchtest du den Eintrag von ${getUserName(entry.expand?.user)} wirklich löschen?`,
        onConfirm: () => deleteEntryMutation.mutate()
    })

    return <>
        <ConfirmModal/>

        <UpdateEventListSlotEntryStatusModal
            opened={showStatusEditModal}
            close={showStatusEditModalHandler.close}
            entry={entry}
            refetch={refetch}
        />

        <MoveEventListSlotEntryModal
            opened={showMoveEntryModal}
            close={showMoveEntryModalHandler.close}
            entry={entry}
            refetch={refetch}
        />

        <UpdateEventListSlotEntryFormModal
            opened={showEditFormModal}
            close={showEditFormModalHandler.close}
            refetch={refetch}
            entry={entry}
        />

        <Button
            leftSection={<IconCheckupList size={16}/>}
            variant={"light"}
            size={"compact-xs"}
            onClick={showStatusEditModalHandler.toggle}
        >
            Status bearbeiten
        </Button>

        <Menu>
            <Menu.Target>
                <ActionIcon
                    size="sm"
                    variant="light"
                    color="blue"
                >
                    <IconSettings size={16}/>
                </ActionIcon>
            </Menu.Target>
            <Menu.Dropdown>
                <Menu.Item
                    leftSection={<IconArrowsMove size={16}/>}
                    onClick={showMoveEntryModalHandler.toggle}
                >
                    Eintrag verschieben
                </Menu.Item>
                <Menu.Item
                    leftSection={<IconForms size={16}/>}
                    onClick={showEditFormModalHandler.toggle}
                >
                    Formular
                </Menu.Item>
                <Menu.Item
                    color={"red"} leftSection={<IconTrash size={16}/>}
                    onClick={toggleConfirmModal}
                >
                    Löschen
                </Menu.Item>
            </Menu.Dropdown>
        </Menu>
    </>

}