import {EventListSlotsWithEntriesCountModel} from "@/models/EventTypes.ts";
import {Badge, Group, Progress, Text, ThemeIcon, Tooltip} from "@mantine/core";
import {IconX} from "@tabler/icons-react";
import classes from "./ListSlotProgress.module.css"

/**
 * Displays a progress status for the number of entries in a slot.
 * If the slot is unlimited or full, the message will reflect that.
 * @param slot The slot to display the progress for
 */
export default function EventListSlotProgress({slot}: { slot: EventListSlotsWithEntriesCountModel }) {

    // if there are no max entries, the slot is unlimited
    if (slot.maxEntries === 0 || slot.maxEntries === null) {
        return (
            <Group align={"center"} justify={"center"}>
                <Tooltip
                    label={`${slot.entriesCount} Plätze belegt (unbegrenzt)`}
                    position={"top"} withArrow color={"teal"}
                >
                    <Badge color={"teal"}>{slot.entriesCount} / ...</Badge>
                </Tooltip>
                <Text mt={3} fz="sm" c={"teal"}>Unbegrenzte Plätze</Text>
            </Group>
        )
    }

    // if the slot is full
    if (slot.maxEntries < slot.entriesCount) {
        return (
            <Group align={"center"} justify={"center"}>
                <ThemeIcon size={"sm"} variant={"transparent"} color={"orange"}>
                    <IconX/>
                </ThemeIcon>
                <Text mt={3} fz="sm" fw={700} c={"orange"}>Alle Plätze <u>{slot.entriesCount}/{slot.maxEntries}</u> belegt</Text>
            </Group>
        )
    }

    const freeSlots = slot.maxEntries - slot.entriesCount
    const occupiedSlots = slot.entriesCount

    // if the slot is not full and has a max entry count
    return <>
        <Progress.Root size="xl" classNames={classes}>
            {
                occupiedSlots > 0 &&
                <Tooltip
                    label={`Belegte Plätze (${occupiedSlots}/${slot.maxEntries})`}
                    position={"top"} withArrow color={"orange"}
                >
                    <Progress.Section value={occupiedSlots * 100} color="orange">
                        <Progress.Label>{occupiedSlots}</Progress.Label>
                    </Progress.Section>
                </Tooltip>
            }
            <Tooltip
                label={`Freie Plätze (${freeSlots}/${slot.maxEntries})`}
                position={"top"} withArrow color={"teal"}
            >
                <Progress.Section value={freeSlots * 100} color="teal">
                    <Progress.Label>{freeSlots}</Progress.Label>
                </Progress.Section>
            </Tooltip>
        </Progress.Root>
    </>
}

