import {areDatesSame, formatDuration} from "@/lib/datetime.ts";
import {Group, ThemeIcon} from "@mantine/core";
import {IconCalendar, IconCalendarClock, IconClock, IconHourglass} from "@tabler/icons-react";
import dayjs from "dayjs";
import TextWithIcon from "@/components/layout/TextWithIcon";

/**
 * Renders a date range in a human-readable format
 *
 * e.g. [IconClock] 17:00-18:00 [IconCalender] 24.04.24 (1 Std)
 * @param start - start date
 * @param end - end date
 */
export const RenderDateRange = ({start, end}: { start: Date, end: Date }) => {

    const duration = formatDuration(start, end)

    // case for same date
    if (areDatesSame(start, end)) {
        return <Group gap={"xs"}>
            <TextWithIcon icon={
                <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                    <IconClock/>
                </ThemeIcon>
            }>
                {dayjs(start).format("HH:mm")}
                {"-"}
                {dayjs(end).format("HH:mm")}
            </TextWithIcon>

            <TextWithIcon icon={
                <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                    <IconCalendar/>
                </ThemeIcon>
            }>
                {dayjs(start).format("DD.MM.YY")}
            </TextWithIcon>

            <TextWithIcon icon={
                <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                    <IconHourglass/>
                </ThemeIcon>
            }>
                {duration}
            </TextWithIcon>
        </Group>
    }

    // case both dates start at 00:00:00
    if (start.getHours() === 0 && start.getMinutes() === 0 && start.getSeconds() === 0 &&
        end.getHours() === 0 && end.getMinutes() === 0 && end.getSeconds() === 0) {
        return <Group gap={'xs'}>
            <TextWithIcon icon={
                <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                    <IconCalendar/>
                </ThemeIcon>
            }>
                {dayjs(start).format("DD.MM.YY")}
            </TextWithIcon>

            {"bis"}

            <TextWithIcon icon={
                <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                    <IconCalendar/>
                </ThemeIcon>
            }>
                {dayjs(end).format("DD.MM.YY")}
            </TextWithIcon>

            <TextWithIcon icon={
                <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                    <IconHourglass/>
                </ThemeIcon>
            }>
                {duration}
            </TextWithIcon>
        </Group>
    }

    // case different dates and times
    return <Group gap={'xs'}>
        <TextWithIcon icon={
            <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                <IconCalendarClock/>
            </ThemeIcon>
        }>
            {dayjs(start).format("HH:mm DD.MM.YY")}
        </TextWithIcon>

        {"bis"}

        <TextWithIcon icon={
            <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                <IconCalendarClock/>
            </ThemeIcon>
        }>
            {dayjs(end).format("HH:mm DD.MM.YY")}
        </TextWithIcon>

        <TextWithIcon icon={
            <ThemeIcon variant={"transparent"} size={"xs"} color={"gray"}>
                <IconHourglass/>
            </ThemeIcon>
        }>
            {duration}
        </TextWithIcon>
    </Group>
}