import {EventListSlotEntriesWithUserModel} from "@/models/EventTypes.ts";
import {PocketBaseErrorAlert, usePB} from "@/lib/pocketbase.tsx";
import {useMutation} from "@tanstack/react-query";
import {FieldEntries} from "@/components/formUtil/FromInput/types.ts";
import {showSuccessNotification} from "@/components/util.tsx";
import {Modal} from "@mantine/core";
import FormInput from "@/components/formUtil/FromInput";
import {getUserName, RenderUserName} from "@/components/auth/modals/util.tsx";

export const UpdateEventListSlotEntryFormModal = ({opened, close, refetch, entry}: {
    opened: boolean,
    close: () => void,
    refetch: () => void,
    entry: EventListSlotEntriesWithUserModel
}) => {

    const {pb} = usePB()

    const mutation = useMutation({
        mutationFn: async (values: FieldEntries) => {
            console.log(entry)
            return await pb.collection("eventListSlotEntries").update(entry.id, {
                entryQuestionData: values
            })
        },
        onSuccess: () => {
            showSuccessNotification(`Formular Daten von ${getUserName(entry.expand?.user)} erfolgreich aktualisiert`)
            refetch()
            close()
        }
    })

    const questionSchemaFields = [
        ...entry.entryQuestionSchema?.fields ?? [],
        ...entry.defaultEntryQuestionSchema?.fields ?? [],
    ]

    return <Modal
        size={"lg"}
        opened={opened}
        onClose={close}
        title={<> Eintrag von <b><RenderUserName user={entry.expand?.user}/></b> bearbeiten </>}
    >
        <PocketBaseErrorAlert error={mutation.error}/>

        <FormInput
            schema={{fields: questionSchemaFields}}
            onSubmit={mutation.mutateAsync}
            onAbort={close}
            initialData={entry.entryQuestionData ?? undefined}
        />
    </Modal>
}