import {EventListSlotEntriesWithUserModel} from "@/models/EventTypes.ts";
import {PocketBaseErrorAlert, usePB} from "@/lib/pocketbase.tsx";
import {useMutation} from "@tanstack/react-query";
import {FieldEntries} from "@/components/formUtil/FromInput/types.ts";
import {showSuccessNotification} from "@/components/util.tsx";
import {Alert, Modal} from "@mantine/core";
import InnerHtml from "@/components/InnerHtml";
import {RenderDateRange} from "./RenderDateRange.tsx";
import FormInput from "@/components/formUtil/FromInput";
import {getUserName, RenderUserName} from "@/components/auth/modals/util.tsx";

export const UpdateEventListSlotEntryStatusModal = ({opened, close, refetch, entry}: {
    opened: boolean,
    close: () => void,
    refetch: () => void,
    entry: EventListSlotEntriesWithUserModel
}) => {

    const {pb} = usePB()

    const statusSchemaFields = [
        ...entry.entryStatusSchema?.fields ?? [],
        ...entry.defaultEntryStatusSchema?.fields ?? [],
    ]

    const mutation = useMutation({
        mutationFn: async (values: FieldEntries) => {
            return await pb.collection("eventListSlotEntries").update(entry.id, {
                entryStatusData: values
            })
        },
        onSuccess: () => {
            showSuccessNotification(`Status von ${getUserName(entry.expand?.user)} erfolgreich aktualisiert`)
            refetch()
            close()
        }
    })

    return <Modal
        size={"lg"}
        opened={opened}
        onClose={close}
        title={<> Eintrag von <b><RenderUserName user={entry.expand?.user}/></b> bearbeiten </>}
    >
        <PocketBaseErrorAlert error={mutation.error}/>


        <Alert title={`${entry.listName}`} color={"blue"} mb={"sm"}>
            <RenderDateRange start={new Date(entry.slotStartDate)} end={new Date(entry.slotEndDate)}/>
        </Alert>

        {(entry.listDescription || entry.slotDescription) && (
            <Alert title={"Beschreibung"} color={"blue"} mb={"sm"}>

                {entry.listDescription && (
                    <InnerHtml html={entry.listDescription}/>
                )}

                {entry.slotDescription && (
                    <InnerHtml html={entry.slotDescription}/>
                )}

            </Alert>
        )}

        <FormInput
            schema={{fields: statusSchemaFields}}
            onSubmit={mutation.mutateAsync}
            onAbort={close}
            initialData={entry.entryStatusData ?? undefined}
        />
    </Modal>
}