import {EventModel} from "@/models/EventTypes.ts";
import {usePB} from "@/lib/pocketbase.tsx";
import {useSettings} from "@/lib/settings.ts";
import {LdapGroupModel} from "@/models/AuthTypes.ts";


export const useEventRights = (event?: EventModel) => {
    const {user} = usePB()

    const settings = useSettings()

    const isStex = !!(
        user &&
        settings?.stexGroupId?.value !== undefined &&
        user.expand?.memberOf?.map((g: LdapGroupModel) => g.cn).includes(settings.stexGroupId.value)
    )
    const isEventAdmin = !!(user && event && event.eventAdmins.includes(user.id))
    const isEventListAdmin = !!(user && event && event.eventListAdmins.includes(user.id))

    return {
        canEditEvent: isEventAdmin || isStex,
        canEditEventList: isEventListAdmin || isEventAdmin || isStex
    }
}