import {EventCalendar} from "@/pages/events/EventOverview/EventCalendar.tsx";
import {Alert, Button, Group, ThemeIcon, Title} from "@mantine/core";
import {IconConfetti, IconHandLoveYou, IconQrcode} from "@tabler/icons-react";
import {usePB} from "@/lib/pocketbase.tsx";
import {NavLink} from "react-router-dom";


export default function HomePage() {

    const {user} = usePB()

    const nav = [
        {
            title: "Events",
            icon: <IconConfetti/>,
            to: `/events`
        },
        {
            title: "QR Generator",
            icon: <IconQrcode/>,
            to: `/util/qr`
        }
    ]

    return <>
        <div className={"section"}>

            <Title order={1}>
                <ThemeIcon color={"green"} variant={"transparent"} mr={"sm"}>
                    <IconHandLoveYou/>
                </ThemeIcon>
                Hallo

                {user && `, ${user.username}`}
            </Title>

            {!user && <>
                <Alert color={"blue"} title={"Willkommen bei der StuVe!"}>
                    Um alle Funktionen nutzen zu können, logge dich bitte mit deinem StuVe IT Account ein.
                </Alert>
            </>}
        </div>

        <Group className={"section-transparent"}>
            {
                nav.map(({title, icon, to}) => (
                    <NavLink to={to} replace key={to}>
                        {({isActive}) => (
                            <Button
                                radius={"xl"}
                                component={"span"}
                                color={isActive ? "green" : "blue"}
                                variant={"outline"}
                                size={"md"}
                                leftSection={icon}
                            >
                                {title}
                            </Button>
                        )}
                    </NavLink>
                ))
            }
        </Group>

        <div className={"section"}>
            <Title order={2}>StuVe Events</Title>

            <EventCalendar/>
        </div>
    </>
}