import {useForm} from "@mantine/form";
import {Button, ColorInput, NumberInput, Select, TextInput, Tooltip} from "@mantine/core";
import classes from "./index.module.css";
import {createQRCodeUrl, ErrorCorrectionLevel} from "@/lib/util.ts";
import {CodeHighlight} from "@mantine/code-highlight";
import {IconDownload, IconQrcode} from "@tabler/icons-react";
import {useSearchParams} from "react-router-dom";

export default function QRCodeGenerator() {

    const [searchParams] = useSearchParams()

    const formValues = useForm({
        initialValues: {
            data: searchParams.get("data") ?? "",
            ecc: "M" as ErrorCorrectionLevel,
            scale: 1,
            border: 1,
            color: "#000000",
            colorBackground: "#ffffff"
        }
    })

    const qrCodeLink = createQRCodeUrl(formValues.values)

    return (
        <>
            <div className={"section"}>
                <div className={"section-icon"}>
                    <IconQrcode/>
                </div>
                <h1>QR Code Generator</h1>
            </div>

            <div className={"section"}>
                <h2>How to</h2>
                <p>
                    Mit diesem Tool kannst du einen QR Code generieren. Diesen kannst du dann im Wiki oder im Pad
                    einbetten. Das heißt, dass der QR Code dann auf dem Pad oder im Wiki angezeigt wird ohne ihn als
                    Datei hochladen zu müssen.
                    Es ist möglich, die Größe des QR Codes sowie die Farben anzupassen.
                </p>
            </div>

            <div className={`section`}>
                <h2>Daten</h2>

                <div className={`${classes.container}`}>
                    <TextInput
                        label={"Daten"}
                        autoFocus={true}
                        description={"z.B. URL, Text, etc."}
                        placeholder={"Tippe etwas ein um einen QR Code zu generieren ..."}
                        required
                        {...formValues.getInputProps("data")}
                    />
                    <Select
                        label={"Fehlerkorrektur"}
                        description={"Wie stark soll die Fehlerkorrektur sein?"}
                        placeholder={"Wähle die Fehlerkorrektur"}
                        data={[
                            {value: 'L', label: 'Gering'},
                            {value: 'M', label: 'Mittel'},
                            {value: 'Q', label: 'Hoch'},
                            {value: 'H', label: 'Sehr hoch'},
                        ]}
                        {...formValues.getInputProps("ecc")}
                    />

                    <NumberInput
                        label="Skalierung"
                        description="Die Größe des QR Codes"
                        placeholder="Skalierung"
                        min={1}
                        {...formValues.getInputProps("scale")}
                    />

                    <NumberInput
                        label="Rand"
                        description="Der Rand des QR Codes"
                        placeholder="Rand"
                        min={0}
                        {...formValues.getInputProps("border")}
                    />

                    <ColorInput
                        label={"Farbe"}
                        description={"Die Farbe des QR Codes"}
                        placeholder={"Farbe"}
                        {...formValues.getInputProps("color")}
                    />

                    <ColorInput
                        label={"Hintergrundfarbe"}
                        description={"Die Hintergrundfarbe des QR Codes"}
                        placeholder={"Hintergrundfarbe"}
                        {...formValues.getInputProps("colorBackground")}
                    />
                </div>

                {formValues.values.data && (
                    <Tooltip
                        multiline
                        withArrow
                        color={"blue"}
                        label={<>
                            Um den QR Code ins Wiki oder ins Pad einzubinden den Link unten verwenden
                        </>}
                    >
                        <Button
                            component={"a"}
                            href={qrCodeLink}
                            leftSection={<IconDownload/>}
                            mt={"sm"}
                        >
                            Download SVG
                        </Button>
                    </Tooltip>
                )}
            </div>

            {formValues.values.data && (
                <div className={`section`}>
                    <h2>Vorschau</h2>

                    <div className={classes.preview}>
                        <img src={qrCodeLink} alt={"QR Code Vorschau"}/>
                    </div>

                    <h2>Markdown Link</h2>

                    <CodeHighlight code={
                        `![QR Code for ${formValues.values.data}](${qrCodeLink})`
                    } language="markdown"/>

                    <h2>HTML Image Tag</h2>

                    <CodeHighlight code={
                        `<img src="${qrCodeLink}" alt="QR Code for ${formValues.values.data}"/>`
                    } language="html"/>
                </div>
            )}
        </>
    )
}